Command suffixes which have special meaning
===========================================

Some commands like `step`, or `list` do different things when an
alias to the command ends in a particular suffix like `>`.

Here are a list of commands and the special suffixes:

    command   suffix
    -------   ------
    list       >
    step       +,-,<,>
    next       +,-,<,>
    quit       !
    kill       !
    eval       ?

See the help on the specific commands listed above for the specific
meaning of the suffix.
